@@ -347,7 +347,7 @@ install_d2_standalone() {
 
 install_d2_brew() {
   header "installing d2 with homebrew"
-  sh_c brew tap terrastruct/d2
+  sh_c brew update
   sh_c brew install d2
 }
 
@@ -390,8 +390,8 @@ install_tala_standalone() {
 
 install_tala_brew() {
   header "installing tala with homebrew"
-  sh_c brew tap terrastruct/d2
-  sh_c brew install tala
+  sh_c brew update
+  sh_c brew install terrastruct/tap/tala
 }
 
 uninstall() {
@@ -502,11 +502,6 @@ fetch_gh() {
   sh_c mv "$file.inprogress" "$file"
 }
 
-brew() {
-  # Makes brew sane.
-  HOMEBREW_NO_INSTALL_CLEANUP=1 HOMEBREW_NO_AUTO_UPDATE=1 command brew "$@"
-}
-
 # The main function does more than provide organization. It provides robustness in that if
 # the install script was to only partial download into sh, sh will not execute it because
 # main is not invoked until the very last byte.
