@@ -32,7 +32,7 @@ import (
 	"unicode/utf16"
 	"unicode/utf8"
 
-	"oss.terrastruct.com/xdefer"
+	"oss.terrastruct.com/util-go/xdefer"
 )
 
 // Node is the base interface implemented by all d2 AST nodes.
