@@ -7,11 +7,14 @@ import (
 func testRegression(t *testing.T) {
 	tcs := []testCase{
 		{
-			name: "dagre_id_with_newline",
+			name: "dagre_special_ids",
 			script: `
 ninety\nnine
 eighty\reight
 seventy\r\nseven
+a\\yode -> there
+a\\"ode -> there
+a\\node -> there
 `,
 		},
 		{
@@ -25,8 +28,12 @@ B: goodbye {
   shape: sequence_diagram
 }
 
-A->B
-`,
+A->B`,
+		}, {
+			name: "sequence_diagram_span_cover",
+			script: `shape: sequence_diagram
+b.1 -> b.1
+b.1 -> b.1`,
 		},
 	}
 
